// Declare the ROOT macro (= C++ function)
#include<sstream>
void histo()
{
  // Reset the ROOT session (in case other macros have been run already)
  gROOT->Reset();

  int bins = 42;
  double fromHrs = 120/60.;
  double toHrs   = 330/60.;

  int noCls = 9; // nine age classes
  int ageCls[] = { 18, 20, 30, 40, 45, 50, 55, 60, 65 };
  TH1D* cls2hist[66]; // hold histograms for each age-class

  // Define ("book") the histogram:
  TH1D* h1 = new TH1D("Finishing times (men)", 
		      "Zurich Marathon 2006", bins, fromHrs, toHrs );

  // Initialize one histogram per age class
  for ( int i=0; i < noCls; i++ ) {
    ostringstream ost;
    ost << "Class " << i;
    string* title = new string(ost.str()); // create new title string on the heap
    TH1D* h = new TH1D(title->c_str(), title->c_str(), bins, fromHrs, toHrs);
    cls2hist[ageCls[i]] = h;
  }

  // Open the data file.
  ifstream file("marathon.txt");
  int count = 0; // Counter

  // Read in the data file
  while ( ! file.eof() ) {
    count++; 
    int cls; // age classification
    double time; // finishing time
    file >> cls;
    file >> time;
    
    // Fill the histogram with the finishing time
    h1->Fill(time/60.);
    
    // Loop over all age-classes, fill the histogram
    // of the appropriage age class
    for ( int i=0; i<noCls; i++ ) {
      if ( ageCls[i]==cls ) {
	cls2hist[ageCls[i]]->Fill(time/60.);
      }
    }
  } 
  
  file.close();

  // Draw the histogram.
  h1->Draw();

  // Output of the mean finishing times per age class
  for ( int i=0; i<noCls; i++ ){
    cout << "Class: " << ageCls[i] << " Mean Finishing Time(hrs): "
	 << cls2hist[ageCls[i]]->GetMean() 
	 << endl;
  }
  cout << "Overall mean Finishing Time(hrs)  : " << h1->GetMean() << endl;
}
 
