#include "EnergyCollector.hh"

#include "G4Step.hh"
#include "G4TouchableHistory.hh"

#include "globals.hh"


/**
 * Opens a file to store simulation output.
 */
EnergyCollector::EnergyCollector()
  : G4VSensitiveDetector("PositronEnergyCollector"),
    file_("epos.txt")
{
  positronEnergy_ = 0;
  G4cout << "-- EnergyCollector: constructed. " << G4endl;
}


/**
 * Closes the file into which simulation output is stored.
 */
EnergyCollector::~EnergyCollector()
{
  
  // Close the file
  file_.close();

  G4cout << "-- EnergyCollector: destructed." << G4endl;
}


/**
 * Resets the flag concerning the positron energy
 */
void EnergyCollector::Initialize(G4HCofThisEvent*)
{
  positronEnergy_ = 0;
}


#include "G4Track.hh"
#include "G4ParticleDefinition.hh"

/**
 * At each step, we have to ask the step which particle
 * is being processed. If it's a positron, we save its
 * energy value to a file and set a flag to true in order
 * to save the energy only of the first step of the first
 * positron seen by this method.
 */
G4bool EnergyCollector::ProcessHits(G4Step* aStep,
				    G4TouchableHistory*)
{
  G4ParticleDefinition* particle =
    aStep->GetTrack()->GetDefinition();

  if ( particle->GetPDGEncoding() == -11 ) { // positron!
    
    G4double positronEnergy = aStep->GetTrack()->GetKineticEnergy();
    positronEnergy = positronEnergy;
    if ( positronEnergy > positronEnergy_ ) {
      positronEnergy_ = positronEnergy;
    }
  }

  // We always return true .... 
  // (I did not find a G4 document describing the purpose of this boolean..)
  return true;
}


/**
 * Write to file.
 */
void EnergyCollector::EndOfEvent(G4HCofThisEvent*)
{
  file_ << positronEnergy_/GeV << G4endl;
}


